@@ -6,7 +6,7 @@ from nonebot.internal.adapter import Event
 from nonebot.internal.matcher import Matcher
 from nonebot.typing import T_State
 
-from ml_hitwh.errors import BadRequestError
+from nonebot_plugin_mahjong_utils.errors import BadRequestError
 from nonebot_plugin_mahjong_utils.interceptors.handle_error import handle_error
 from nonebot_plugin_mahjong_utils.utils.mapper import map_han_hu
 
